# RPM spec file for Snd by Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
#
# the old scheme of trying to get meaningful names for libraries and other
# dependencies is gone. Things like apt for rpm make that unnecessary and 
# the dream of rpms that can be used on any distribution was just that, 
# a dream

%define ver      7.2
%define rel      1
%define tarname  snd-7
%define snd_date "02/20/2004"

%define sndlib          %{_libdir}/snd
%define	desktop_vendor	planetccrma
%define desktop_utils   %(if which desktop-file-install &>/dev/null ; then echo "yes" ; fi)
%define redhat_release  %(if [ -e /etc/redhat-release ] ; then awk '{print $5}' /etc/redhat-release ; fi)

#### BEGIN BUILD CONFIGURATION VARIABLES ####
#
# define which binary rpms are generated:
#   build_motif_gui:  --define "build_motif_gui 1|0"
#   build_gtk_gui:    --define "build_gtk_gui 0|1"
#   build_utils:      --define "build_utils 1|0"
#
# do we create a shared sndlib package? [not working yet]
#   build_sndlib:     --define "build_sndlib 0"
#
# define sound api to be used:
#   sound_api:        --define "sound_api alsa|oss"
#
# build with ladspa support:
#   with_ladspa:      --define "with_ladspa 1|0"
#
# build with opengl support:
#   with_opengl:      --define "with_opengl 1|0"
#
# set this to 1 if you want to link statically against alsa
#
#   if the binary is statically linked then the requirement
#   for alsa to be preinstalled can be dropped and the resulting
#   binary can run in either an alsa or oss only environment, 
#   snd will autoswitch to the existing driver giving alsa
#   priority. But it will make the executable bigger so if you
#   have alsa installed you should set this to 0
#
#  with_static_alsa:  --define "with_static_alsa 0"
#
# set this to 1 if you want to depend on the guile-gtk library
# (0 for now till it can be compiled with guile 1.5.x)
#
#  with_guile_gtk:    --define "with_guile_gtk 0"
#

%{!?build_motif_gui:  %{expand: %%define build_motif_gui 1}}
%{!?build_gtk_gui:    %{expand: %%define build_gtk_gui 0}}
%{!?build_utils:      %{expand: %%define build_utils 1}}
%{!?build_sndlib:     %{expand: %%define build_sndlib 0}}
%{!?sound_api:        %{expand: %%define sound_api alsa}}

%{!?with_jack:        %{expand: %%define with_jack --with-jack}}

%{!?with_ladspa:      %{expand: %%define with_ladspa 1}}
%{!?with_opengl:      %{expand: %%define with_opengl 1}}
%{!?with_static_alsa: %{expand: %%define with_static_alsa 0}}
%{!?with_guile_gtk:   %{expand: %%define with_guile_gtk 0}}

# at ccrma snd lives in the shared server space, not in each
# individual machine, but I still want to install the icon,
# menu entry and docs in every machine. Set to 1 when building
# a version with a custom /etc/snd.conf and no builtin scheme
# code

%{!?build_for_ccrma:  %{expand: %%define build_for_ccrma 0}}

# try to use the separate snd guile package if it exists

%{!?with_snd_guile:  %{expand: %%define with_snd_guile 0}}

# define any extra configure options here:
# currently prefix, guile, run optimizer.

%define snd_config_options --prefix=%{_prefix} --with-guile=yes --with-run=yes %{with_jack}

#
#### END BUILD CONFIGURATION VARIABLES ####

# autodetection of distribution we are building in, used for menus:

%define linux_flavor %(%{_sourcedir}/snd-detect-flavor)

# command line configuration options

%if "%{with_ladspa}" == "1"
    %define ladspa --with-ladspa
%else
    %define ladspa "%{nil}"
%endif
%if "%{sound_api}" == "alsa" && "%{with_static_alsa}" == "0"
    %define sound_driver --with-alsa=yes
%endif
%if "%{sound_api}" == "alsa" && "%{with_static_alsa}" == "1"
    %define sound_driver --with-static-alsa=yes
%endif
%if "%{sound_api}" != "alsa"
    %define sound_driver --with-alsa=no
%endif
%if "%{with_opengl}" == "1"
    %define opengl --with-gl
%else
    %define opengl "%{nil}"
%endif
%if "%{build_sndlib}" == "1"
    %define sharedsndlib --with-shared-sndlib
%else
    %define sharedsndlib "%{nil}"
%endif
%if "%{sound_api}" == "alsa"
    %define motif_name          motif
    %define gtk_name            gtk
    %define utils_name          utils
    %define motif_name_conflict motif-oss
    %define gtk_name_conflict   gtk-oss
    %define utils_name_conflict utils-oss
%else
    %define motif_name          motif-oss
    %define gtk_name            gtk-oss
    %define utils_name          utils-oss
    %define motif_name_conflict motif-alsa
    %define gtk_name_conflict   gtk-alsa
    %define utils_name_conflict utils-alsa
%endif


Summary:	A sound editor (%{ver}, %{snd_date})
Name:		snd
Version:	%{ver}
Release:        %{?release_prefix:%{release_prefix}.}%{rel}%{?release_suffix:.%{release_suffix}}
Copyright:	LGPL
Group:		Applications/Multimedia
Source:		ftp://ccrma-ftp.stanford.edu/pub/Lisp/%{tarname}.tar.gz
Source2:        snd-detect-flavor
Source3:        snd.png
# old spec files (for reference)
Source100:      snd-5.1-1.spec
Source101:      snd-5.2-1.spec
Source102:      snd-5.2-2.spec
Source105:      snd-5.8-1.spec
Source106:      snd-6.6-1.spec
Patch0:         snd-7.1-createselector.patch
URL:		http://www-ccrma.stanford.edu/software/snd/
Vendor:		CCRMA/Music Stanford University
Packager:	Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
Distribution:   Planet CCRMA
Buildroot:      %{_tmppath}/%{name}-%{version}-root
%if "%{with_ladspa}" == "1"
BuildRequires:  ladspa-sdk
%endif

%description
Snd is a sound editor modelled loosely after Emacs and an old, sorely-missed
PDP-10 sound editor named Dpysnd. It can accomodate any number of sounds
each with any number of channels, and can be customized and extended
using guile and guile-gtk. Snd is free (LGPL); the code is available via
anonymous ftp at ccrma-ftp.stanford.edu as pub/Lisp/%{tarname}.tar.gz.

This package contains snd version %{ver}, dated %{snd_date}.

%package %{motif_name}
Summary:        Motif/%{sound_api} version of snd (%{ver}, %{snd_date})
Group:		Applications/Multimedia
Requires:       snd == %{ver}
Requires:       openmotif
Conflicts:      %{motif_name_conflict}
%if "%{linux_flavor}" == "RedHat"
%if "%{redhat_release}" == "7.3" || "%{redhat_release}" == "8.0"
Obsoletes:      snd-guile
%endif
%endif

%description %{motif_name}
A version of the Snd editor (%{ver} of %{snd_date}) compiled with the
Motif gui and support for the %{sound_api} sound drivers api.

%if "%{sound_api}" == "alsa" && "%{with_static_alsa}" == "1"
This package will use the oss sound driver api if alsa is not installed. 
%endif

%package %{gtk_name}
Summary:        Gtk/%{sound_api} version of snd (%{ver}, %{snd_date})
Group:		Applications/Multimedia
Requires:       snd == %{ver}
Conflicts:      %{gtk_name_conflict}
%if "%{linux_flavor}" == "RedHat"
%if "%{redhat_release}" == "7.3" || "%{redhat_release}" == "8.0"
Obsoletes:      snd-guile
%endif
%endif

%description %{gtk_name}
A version of the Snd editor (%{ver} of %{snd_date}) compiled with the gtk
gui and support for the %{sound_api} api sound drivers. 

%if "%{sound_api}" == "alsa" && "%{with_static_alsa}" == "1"
This package will use the oss sound driver api if alsa is not installed. 
%endif

%package %{utils_name}
Summary:        %{sound_api} versions of sndplay and friends (%{ver}, %{snd_date})
Group:		Applications/Multimedia
Conflicts:      %{utils_name_conflict}
# always conflict with the sndplay packages from cm/clm/cmn
Conflicts:      sndplay-oss sndplay

%description %{utils_name}
Command line utilities included with the snd sound editor (%{ver} of %{snd_date})
compiled with support for the %{sound_api} api sound drivers. 

%if "%{sound_api}" == "alsa" && "%{with_static_alsa}" == "1"
This package will use the oss sound driver api if alsa is not installed. 
%endif

%package -n sndlib
Summary:        Soundfile and audio handler collection
Group:		Applications/Multimedia

%description -n sndlib
The sound library is a collection of sound file and audio hardware
handlers written in C and running currently on SGI (either audio
library), Sun, OSS or ALSA (Linux and others), Mac, Mac OSX, HPUX,
LinuxPPC, and Windoze systems. It provides relatively straightforward
access to many sound file headers and data types, and most of the
features of the audio hardware.

%prep
%setup -q -n %{tarname}

%build
echo "Building on %{linux_flavor}"
echo "Building for %{sound_api} sound api"

%if "%{sound_api}" == "alsa"
export CFLAGS="-DALSA_PCM_OLD_HW_PARAMS_API -DALSA_PCM_OLD_SW_PARAMS_API $CFLAGS"
%endif

%ifos Linux
%ifarch i386 i586 i686

# prepend the local guile bin path to the search path if we use the 
# separate snd specific guile package

%if "%{with_snd_guile}" == "1"
%define guilepath PATH=%{sndlib}/bin:${PATH}
%else
%define guilepath %{nil}
%endif

#--- build snd: Motif version
%if %{build_motif_gui}
    %{guilepath} ./configure %{snd_config_options} --with-static-xm=yes %{sound_driver} %{ladspa} %{opengl} %{sharedsndlib}
%if "%{redhat_release}" == "7.3" || "%{redhat_release}" == "8.0"
#    patch -p1 <%{PATCH0}
%endif
    make
    mv snd snd-%{motif_name}
    make clean
    rm -f config.cache
%endif

#--- build snd: Gtk version
%if %{build_gtk_gui}
    %{guilepath} ./configure %{snd_config_options} --with-gtk=yes %{sound_driver} %{ladspa} %{opengl} %{sharedsndlib}
%if "%{redhat_release}" == "7.3" || "%{redhat_release}" == "8.0"
#    patch -p1 <%{PATCH0}
%endif
    make
    mv snd snd-%{gtk_name}
    make clean
    rm -f config.cache
%endif

#--- build snd: utilities
%if %{build_utils}
    %{guilepath} ./configure %{snd_config_options} %{sound_driver} %{ladspa} %{opengl} %{sharedsndlib}
%if "%{redhat_release}" == "7.3" || "%{redhat_release}" == "8.0"
#    patch -p1 <%{PATCH0}
%endif
    make sndplay sndrecord sndinfo sndsine audinfo
%endif

%else
make -f makefile.ppcrpm
%endif
%endif

%install
rm -rf %{buildroot}

#--- install snd
install -m 755 -d %{buildroot}%{_bindir}/
mkdir -p %{buildroot}%{_mandir}/man1
install -m 644 ${RPM_BUILD_DIR}/%{tarname}/snd.1 %{buildroot}%{_mandir}/man1
%if %{build_motif_gui}
    install -m 755 snd-%{motif_name} %{buildroot}%{_bindir}/snd
%endif
%if %{build_gtk_gui}
    install -m 755 snd-%{gtk_name} %{buildroot}%{_bindir}/
%endif
%if %{build_utils}
    install -m 755 sndplay sndrecord sndinfo sndsine audinfo %{buildroot}%{_bindir}/
%endif

#--- scheme source code
/bin/mkdir -p %{buildroot}/%{sndlib}/scheme
(cd $RPM_BUILD_DIR/%{tarname}/; tar cf - *.scm dlp)|(cd %{buildroot}/%{sndlib}/scheme; tar xpf -)

# change interpreter for finder.scm, otherwise /usr/local/bin/guile is required
perl -p -i -e "s,/usr/local/bin,%{sndlib}/bin,g" %{buildroot}/%{sndlib}/scheme/finder.scm

#--- the snd icon
/bin/mkdir -p %{buildroot}/%{_datadir}/pixmaps/
install -m 644 %{SOURCE3} %{buildroot}%{_datadir}/pixmaps/

%if "%{linux_flavor}" == "RedHat"
  #--- desktop entry for redhat
  cat << EOF > %{desktop_vendor}-%{name}.desktop
[Desktop Entry]
Name=Snd
Comment=the Snd sound editor
Icon=%{name}.png
Exec=%{_bindir}/%{name}
Terminal=false
Type=Application
EOF
%if "%{desktop_utils}" == "yes"
  mkdir -p %{buildroot}%{_datadir}/applications
  desktop-file-install --vendor %{desktop_vendor} \
    --dir %{buildroot}%{_datadir}/applications    \
    --add-category X-Red-Hat-Base                 \
    --add-category Application                    \
    --add-category AudioVideo                     \
    %{desktop_vendor}-%{name}.desktop
%else
  install -d %{buildroot}%{_sysconfdir}/X11/applnk/Multimedia
  install %{desktop_vendor}-%{name}.desktop %{buildroot}%{_sysconfdir}/X11/applnk/Multimedia/
%endif
%endif

%if "%{linux_flavor}" == "Mandrake"
  #--- desktop entry for Mandrake
  install -d %{buildroot}%{_menudir}
  cat << EOF > %{buildroot}%{_menudir}/%{name}
?package(%{name}): \
needs="X11" \
icon="%{name}.png" \
section="Multimedia/Sound" \
title="Snd" \
longtitle="A sound editor" \
command="%{_bindir}/%{name}"
EOF
%endif

#--- a configuration file with the default scheme paths ready to go
mkdir -p %{buildroot}/etc
%if "%{build_for_ccrma}" == "1"
cat << EOF > %{buildroot}/etc/snd.conf
;; Default ccrma snd configuration file [nando, mar 2002]
;;
;; add paths to begin of default load path (last in the list is the 
;; first in the search order)
(set! %load-path (cons "/usr/ccrma/lisp/src/snd/dlp" %load-path))
(set! %load-path (cons "/usr/ccrma/lisp/src/snd" %load-path))
EOF
%else
cat << EOF > %{buildroot}/etc/snd.conf
;; Default snd configuration file [nando, dec 2001]
;;
;; add paths to begin of default load path (last in the list is the 
;; first in the search order)
(set! %load-path (cons "%{sndlib}/scheme/dlp" %load-path))
(set! %load-path (cons "%{sndlib}/scheme" %load-path))
EOF
%endif

%clean
rm -rf %{buildroot}

#--- snd package, just documentation, icon and desktop menu entry
%files
%defattr(-, root, root)
%doc COPYING README.Snd HISTORY.Snd Snd.ad TODO.Snd *.html
%doc *.png
%{_datadir}/pixmaps/snd.png
%if "%{linux_flavor}" == "RedHat"
%if "%{desktop_utils}" == "yes"
%{_datadir}/applications/*%{name}.desktop
%else
%{_sysconfdir}/X11/applnk/Multimedia/%{desktop_vendor}-%{name}.desktop
%endif
%endif
%if "%{linux_flavor}" == "Mandrake"
%{_libdir}/menu/%{name}
%endif
%{_mandir}/man1/snd.1*
#--- scheme code
%if "%{build_for_ccrma}" == "1"
# do not include the scheme code when building for ccrma
%else
%dir %{sndlib}/scheme
%{sndlib}/scheme/*
%endif
#--- default snd configuration file
%config(noreplace) /etc/snd.conf

# arguments to scripts:
# (see http://www-106.ibm.com/developerworks/library/l-rpm3/)
# installing: post = 1
# upgrading:  post = 2 -> postun = 1
# erasing:    postun = 0

#--- snd-motif
%if %{build_motif_gui}
%post %{motif_name}
%if "%{linux_flavor}" == "Mandrake"
%{update_menus}
%endif
%postun %{motif_name}
%if "%{linux_flavor}" == "Mandrake"
%{clean_menus}
%endif

%files %{motif_name}
%defattr(-, root, root)
%{_bindir}/snd
%endif

#--- snd-gtk
%if %{build_gtk_gui}
%post %{gtk_name}
%if "%{linux_flavor}" == "Mandrake"
%{update_menus}
%endif
%postun %{gtk_name}
%if "%{linux_flavor}" == "Mandrake"
%{clean_menus}
%endif

%files %{gtk_name}
%defattr(-, root, root)
%{_bindir}/snd-%{gtk_name}
%endif

#--- snd-utils
%if %{build_utils}
%files %{utils_name}
%defattr(-, root, root)
%{_bindir}/sndplay
%{_bindir}/sndrecord
%{_bindir}/sndinfo
%{_bindir}/sndsine
%{_bindir}/audinfo
%endif


%changelog
* Fri Feb 20 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 7.2-1
- updated to version 7.2
* Mon Jan 12 2004 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 7.1-1
- updated to version 7.1
* Fri Dec 12 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 7-1
- updated to version 7
* Sun Nov  9 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 6.12-1
- spec file tweaks
- added defines to use old alsa api
* Mon Sep 29 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 6.12-1
- updated to 6.12 of 09/29/2003
* Sun Aug 17 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 6.11-1
- updated to 6.11 of 08/15/2003
- no longer use snd-guile packages (switched to guile 6.4 on all
  supported redhat releases, created a new build option to enable it, 
  added Obsoletes tag for 7.3 and 8.0 so that snd-guile is erased by
  the apt dist-upgrade process. 
- added release tags
* Thu May 29 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 6.9-1
- updated to 6.9 of 05/29/2003
* Tue May  6 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 6.8-1
- updated to 6.8 of 05/06/2003
* Tue Apr  8 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 6.7-2
- rebuilt for newer version of fftw
* Sat Mar 22 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 6.7-1
- updated to 6.7
- changed prefix to use default macros
- do not use links to differentiate between motif and gtk version, 
  motif version is now named "snd" and gtk version "snd-gtk"
- do not allow oss and alsa versions of the programs to coexist
- contrib directory for scheme and ruby code is now gone
* Tue Feb 18 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 6.6-1
- updated to 6.6
* Mon Jan 13 2003 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 6.5-1
- updated to 6.5
* Sat Dec 14 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 6.4-1
- updated to 6.4 of 12/14/2002
- changed to proper application group
* Wed Nov 13 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 6.3-1
- updated to 6.3 of 11/13/2002
- added proper redhat 8.0 menu entry
* Wed Oct 16 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 6.2-1
- updated to 6.2 of 10/16/2002
* Tue Sep 17 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 6.1-1
- updated to 6.1 of 09/17/2002
* Mon Aug 26 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 6.0-2
- made dependency on openmotif explicit, otherwise snd appears to be 
  happy with lesstif on redhat 7.2 but fails on startup because of an
  undefined symbol
- updated to snd 6.0 of 08/26/2002
* Wed Aug 14 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 6.0-1
- updated to snd 6.0 of 08/14/2002
* Sun Jul 14 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 5.12-3
- updated to snd of 07/14/2002
* Sat Jul  6 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 5.12-2
- another update, fixed postun installs as they were not working with
  rpm updates (they need to check the argument to the script)
* Tue Jul  2 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 5.12-1
- updated to latest snd
* Sun Jun 16 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 5.11-1
- naming of packages: snd -> base package; snd-motif, snd-gtk main 
  executable, depending on driver either -oss or nothing added; 
  -utils, depending on driver either -oss or nothing added
* Fri Jun 14 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
- simplified spec file, get dependencies automatically
- no longer supports building alsa 0.5 rpms
- no longer supports building with static gsl libraries
- if building for motif always build with static xm library
- simplify snd-detect-flavor, we don't care about releases anymore
- statically linked motif packages are gone, we have openmotif now
* Mon Mar 25 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 5.8-1
- updated to 5.8 03/25/2002
- undo the guile change, after some thought I concluded it is not worth it,
  much better to depend on a separate snd-guile package, as before (save
  the current spec file as a keepsake :-)
- define a build_for_ccrma flag to create an rpm stub for ccrma internal
  use (does not contain any scheme code and has a configuration file that
  to the shared version of the snd source).
* Fri Jan 18 2002 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 5.6-1
- updated to 5.6 01/18/2002
* Mon Dec  3 2001 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 5.5-1
- updated to 5.5 12/03/2001
- incorporated guile 1.5.0 in the rpm (what used to be separate snd-guile 
  package). Currently an ugly hack because configuring and compiling snd
  requires a functional guile, but guile is not installed yet if it is 
  going to be part of snd snd rpms. So for now I do a temporary install
  of guile in the final location (by default /usr/lib/snd) while compiling
  snd. The install is removed at the end of the snd compilation process. 
- install all scheme files in /usr/lib/snd/scheme, including the contrib
  dir
- create a default /etc/snd.conf that adds all scheme source directories
  to the default search path so that "load-from-path" can use just the
  file names. 
* Wed Nov 28 2001 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 5.4-2
- added menu entry for Mandrake 8.x [thanks to Kevin Cosgrove]
- update to snd-5.4 11/28/2001 (with support for new snd_config_get_id 
  in alsa)
* Mon Nov 05 2001 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 5.4-1
- snd 5.4 10/01/2001
- added contrib/ to documentation
- fixed wrong guile_gtk dependency
* Mon Oct  1 2001 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 5.3-1
- snd 5.3 10/01/2001
- generate oss, alsa0.5 and alsa0.9 separate packages, simplifies spec file
- added environment control variables for build configuration through scripts
- added conflicts with sndplay-* packages (from the cm/clm/cmn rpms)
* Thu Sep 27 2001 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 5.2-2
- snd-5.2 09/27/2001
- added man page to files
- removed snd requirement for the snd-utils-* packages
- added package date to description of packages
- added ladspa switch
* Wed Sep  5 2001 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 5.2-1
- snd-5.2
- changed over to guile 1.5, will require snd-guile from now on
- start keeping old spec files for reference
- snd requires gsl >= 0.8, drop references to gsl 0.7
- added xm dependencies
- added menu entry for redhat rpms
- added snd icon
* Thu Jul 26 2001 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
- snd-5.1, alsa 0.9
- added autodetect of installed alsa version (%alsa_ver)
- added autodetect of linux flavor
- autobuild oss only or oss/alsa binary packages
- changed naming of packages and executables to reflect the fact that
  the statically linked alsa package also supports the oss api
* Thu Jul 12 2001 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
- first try at snd-5, snd-guile-1.6, alsa 0.9
* Wed Apr 02 2001 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
- compiled for rh7, snd-4.tar.gz, version 4.12, dated 4/2/2001
* Wed Mar 07 2001 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
- compiled for rh7, snd-4.tar.gz, version 4.11, dated 3/7/2001
* Tue Jan 23 2001 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
- compiled for rh7, suse7.0 and snd-4.tar.gz, version 4.10, dated 1/23/2001
* Wed Jan 17 2001 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
- added support for redhat 7 and finished up support for SuSE 7
* Mon Jan 15 2001 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
- redid the dependencies stuff yet again
- updated to new snd-4.tar.gz of Jan 15 2001
* Sat Jan 13 2001 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
- compiled for snd-4.10 of Jan 13 2000, release set to 1
- patched snd-1.h, added ps_fd field to chan_info structure
- redid the dependencies for all packages. I'm now setting the 
  dependencies manually and trying to be as general as possible 
  so that the packages will run in as many distributions as possible. 
  See the detailed explanation and %defines at the beginning of the 
  spec file. 
- deleted the %{usesndguile} option. I now always prefix the path to 
  search for guile with /usr/lib/snd/bin/. The library will be found
  there at compile time but as the requirements are location independent
  it will be also looked for elsewhere at run time. Thus a distribution
  that comes with the latest guile will meet the requirement and the 
  rpm will install. If snd-guile is not installed or the version of
  guile in the distribution is less than 1.4 the install will fail. 
- added %{build_utils} to enable or not compilation of the command
  line utilities
* Mon Dec 11 2000 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
- compiled for snd-4.9 of Dec 11 2000, release set to 1
- added %{prefix}, removed ${RPM_BUILD_ROOT} prior to install, remove
  -o and -g from the install lines, thanks to Volker Kuhlmann for the tips
- use wildcards in doc file list, added Snd.ad
- added %{usesndguile} option for enabling the search for a private guile
  library
* Mon Nov 20 2000 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
- compiled for snd-4.8 of Nov 20 2000, release set to 1
- fixed dependencies, utils packages do not depend on guile-gtk, 
  only gtk-* do (thanks to Volker Kuhlmann <kuhlmav@elec.canterbury.ac.nz>)
* Mon Oct 16 2000 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
- compiled for snd-4.7, release set to 1
* Thu Sep 28 2000 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
- compiled for snd-4.6 of Sep 28 2000, release set to 1
* Fri Aug 25 2000 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
- added statically linked versions of the motif gui packages
- compiled using snd-4.tar.gz Aug 25 2000
* Mon Aug 21 2000 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
- changed postun to only erase link to binaries if the package being
  installed is the one that set up the link in the first place
- added alsa version number to naming of packages, that will enable
  us to have packages for alsa 0.5.x and 0.6.x in the same directory
* Wed Aug 16 2000 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
- no need to hack configure.in, a simple PATH added to the ./configure
  stage makes sure that the proper guile binary is found...
* Tue Aug 15 2000 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
- created subpackages snd-motif-oss snd-motif-alsa snd-gtk-oss
  snd-gtk-alsa snd-utils-oss snd-utils-alsa
- changed configure.in in snd-4.5 to search for guile first in 
  /usr/lib/snd/, added -rpath to the linker invocation so that 
  it is not necessary to add /usr/lib/snd/lib to /etc/ld.so.conf
- TODO: create a snd-devel package with the include files and sndlib?
* Mon Aug 14 2000 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu>
- added a root install directory so that compiling the package
  does not clobber the real filesystem
- changed prefix to represent everything up to bin|lib|whatever
  (so that prefix=/usr installs in /usr/bin, follow redhat convention)
- changed version numbering, 4.5 refers to the version of the program,
  the release number is the rpm package release number, the .tar.gz 
  file should be named snd-4.5.tar.gz...

